Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(858)

Unified Diff: Source/core/rendering/InlineTextBox.h

Issue 899163003: Move rendering/RenderObject to layout/LayoutObject. (Closed) Base URL: svn://svn.chromium.org/blink/trunk
Patch Set: Created 5 years, 10 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: Source/core/rendering/InlineTextBox.h
diff --git a/Source/core/rendering/InlineTextBox.h b/Source/core/rendering/InlineTextBox.h
index e12d177a90284446bc72bd3839859797858f05cf..1148b2eefdb1a2460a8774f0cc0501093b3c18e7 100644
--- a/Source/core/rendering/InlineTextBox.h
+++ b/Source/core/rendering/InlineTextBox.h
@@ -39,7 +39,7 @@ const unsigned short cFullTruncation = USHRT_MAX - 1;
class InlineTextBox : public InlineBox {
public:
- InlineTextBox(RenderObject& obj, int start, unsigned short length)
+ InlineTextBox(LayoutObject& obj, int start, unsigned short length)
: InlineBox(obj)
, m_prevTextBox(0)
, m_nextTextBox(0)
@@ -118,7 +118,7 @@ private:
virtual void attachLine() override final;
public:
- virtual RenderObject::SelectionState selectionState() const override final;
+ virtual LayoutObject::SelectionState selectionState() const override final;
private:
virtual void clearTruncation() override final { m_truncation = cNoTruncation; }
@@ -153,8 +153,8 @@ public:
void characterWidths(Vector<FloatWillBeLayoutUnit>&) const;
private:
- InlineTextBox* m_prevTextBox; // The previous box that also uses our RenderObject
- InlineTextBox* m_nextTextBox; // The next box that also uses our RenderObject
+ InlineTextBox* m_prevTextBox; // The previous box that also uses our LayoutObject
+ InlineTextBox* m_nextTextBox; // The next box that also uses our LayoutObject
int m_start;
unsigned short m_len;

Powered by Google App Engine
This is Rietveld 408576698